      subroutine uttbxx(wt1,wt2,gt,tmass,twidth,wt)
c-------------------CP3  2009.10-----------------
c
c This subroutine computes an off-shell tensor current from 
c the coupling of two non-propagating tensor bosons.
c
c input:
c       complex wt1(18)           : input non-propagating tensor                                                       t
c       complex wt2(18)         :  input non-propagating tensor                      T
c       complex gt             : coupling constant         gt=-1/Lambda
c output:
c       complex wt(18)         :  tensor 

      implicit none
      double complex wt(18), wt1(18), gt, wt2(18)
      double precision pT(4),pT2,tmass,twidth
      double complex T(6,4),T1(6,4),T2(6,4),d
      double precision MT(4,4)
      integer i, j,m,n
      double complex cZero
      double precision rZero, rTwo
      parameter( rZero = 0.0d0, rTwo = 2.0d0 )
      parameter( cZero = ( 0.0d0, 0.0d0 ) )


      T2(1,1) = wt2(1)
      T2(1,2) = wt2(2)
      T2(1,3) = wt2(3)
      T2(1,4) = wt2(4)
      T2(2,1) = wt2(5)
      T2(2,2) = wt2(6)
      T2(2,3) = wt2(7)
      T2(2,4) = wt2(8)
      T2(3,1) = wt2(9)
      T2(3,2) = wt2(10)
      T2(3,3) = wt2(11)
      T2(3,4) = wt2(12)
      T2(4,1) = wt2(13)
      T2(4,2) = wt2(14)
      T2(4,3) = wt2(15)
      T2(4,4) = wt2(16)
      T2(5,1) = wt2(17)
      T2(6,1) = wt2(18)
 
      T1(1,1) = wt1(1)
      T1(1,2) = wt1(2)
      T1(1,3) = wt1(3)
      T1(1,4) = wt1(4)
      T1(2,1) = wt1(5)
      T1(2,2) = wt1(6)
      T1(2,3) = wt1(7)
      T1(2,4) = wt1(8)
      T1(3,1) = wt1(9)
      T1(3,2) = wt1(10)
      T1(3,3) = wt1(11)
      T1(3,4) = wt1(12)
      T1(4,1) = wt1(13)
      T1(4,2) = wt1(14)
      T1(4,3) = wt1(15)
      T1(4,4) = wt1(16)
      T1(5,1) = wt1(17)
      T1(6,1) = wt1(18)

      T(5,1) = T2(5,1)+T1(5,1)
      T(6,1) = T2(6,1)+T1(6,1)


      do i=1,4
         do j=1,4
            MT(i,j) = 0.0d0
         enddo 
      enddo
      MT(1,1) =  1.0d0
      MT(2,2) = -1.0d0
      MT(3,3) = -1.0d0
      MT(4,4) = -1.0d0
      
    
	
         do m=1,4
           do n=1,4

          T(m,n)= -((2*MT(1,m)*MT(1,n)
     -   - (2*MT(m,n))/3.)*T1(1,2)*T2(1,2)) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(1,2) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(1,2) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(1,2) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(1,3)*T2(1,2) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(1,4)*T2(1,2) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,1)*T2(1,2) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(1,2) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(1,2) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(1,2) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(2,3)*T2(1,2) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(2,4)*T2(1,2) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(3,1)*T2(1,2) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(3,2)*T2(1,2) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(4,1)*T2(1,2) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(4,2)*T2(1,2) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(1,2)*T2(1,3) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(1,3)*T2(1,3) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(1,3) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(1,3) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(1,3) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(1,4)*T2(1,3) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(2,1)*T2(1,3) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(2,3)*T2(1,3) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,1)*T2(1,3) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(1,3) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(1,3) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(1,3) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(3,2)*T2(1,3) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(3,4)*T2(1,3) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(4,1)*T2(1,3) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(4,3)*T2(1,3) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(1,2)*T2(1,4) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(1,3)*T2(1,4) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(1,4)*T2(1,4) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(1,4) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(1,4) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(1,4) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(2,1)*T2(1,4) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(2,4)*T2(1,4) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(3,1)*T2(1,4) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(3,4)*T2(1,4) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,1)*T2(1,4) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(1,4) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(1,4) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(1,4) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(4,2)*T2(1,4) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(4,3)*T2(1,4) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(1,2)*T2(2,1) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(2,1) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(2,1) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,2)*T2(2,1) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(1,3)*T2(2,1) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(1,4)*T2(2,1) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,1)*T2(2,1) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(2,1) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(2,1) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,1)*T2(2,1) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(2,3)*T2(2,1) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(2,4)*T2(2,1) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(3,1)*T2(2,1) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(3,2)*T2(2,1) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(4,1)*T2(2,1) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(4,2)*T2(2,1) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(1,2)*T2(2,3) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(1,3)*T2(2,3) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(2,1)*T2(2,3) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,3)*T2(2,3) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(2,3) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(2,3) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(2,3) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(2,4)*T2(2,3) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(3,1)*T2(2,3) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,2)*T2(2,3) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(2,3) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(2,3) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(2,3) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(3,4)*T2(2,3) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(4,2)*T2(2,3) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(4,3)*T2(2,3) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(1,2)*T2(2,4) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(1,4)*T2(2,4) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(2,1)*T2(2,4) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(2,3)*T2(2,4) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,4)*T2(2,4) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(2,4) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(2,4) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(2,4) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(3,2)*T2(2,4) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(3,4)*T2(2,4) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(4,1)*T2(2,4) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,2)*T2(2,4) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(2,4) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(2,4) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(2,4) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(4,3)*T2(2,4) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(1,2)*T2(3,1) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(1,3)*T2(3,1) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(3,1) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(3,1) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,3)*T2(3,1) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(1,4)*T2(3,1) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(2,1)*T2(3,1) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(2,3)*T2(3,1) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,1)*T2(3,1) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(3,1) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(3,1) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,1)*T2(3,1) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(3,2)*T2(3,1) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(3,4)*T2(3,1) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(4,1)*T2(3,1) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(4,3)*T2(3,1) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(1,2)*T2(3,2) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(1,3)*T2(3,2) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(2,1)*T2(3,2) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,3)*T2(3,2) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(3,2) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(3,2) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,3)*T2(3,2) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(2,4)*T2(3,2) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(3,1)*T2(3,2) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,2)*T2(3,2) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(3,2) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(3,2) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,2)*T2(3,2) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(3,4)*T2(3,2) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(4,2)*T2(3,2) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(4,3)*T2(3,2) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(1,3)*T2(3,4) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(1,4)*T2(3,4) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(2,3)*T2(3,4) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(2,4)*T2(3,4) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(3,1)*T2(3,4) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(3,2)*T2(3,4) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,4)*T2(3,4) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(3,4) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(3,4) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(3,4) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(4,1)*T2(3,4) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(4,2)*T2(3,4) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,3)*T2(3,4) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(3,4) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(3,4) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(3,4) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(1,2)*T2(4,1) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(1,3)*T2(4,1) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(1,4)*T2(4,1) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(4,1) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(4,1) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(1,4)*T2(4,1) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(2,1)*T2(4,1) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(2,4)*T2(4,1) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(3,1)*T2(4,1) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(3,4)*T2(4,1) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,1)*T2(4,1) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(4,1) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(4,1) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,1)*T2(4,1) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(4,2)*T2(4,1) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(4,3)*T2(4,1) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(1,2)*T2(4,2) - 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(1,4)*T2(4,2) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(2,1)*T2(4,2) + 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(2,3)*T2(4,2) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(2,4)*T2(4,2) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(4,2) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(4,2) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(2,4)*T2(4,2) - 
     -  2*(MT(3,n)*MT(4,m) + MT(3,m)*MT(4,n))*T1(3,2)*T2(4,2) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(3,4)*T2(4,2) + 
     -  2*(MT(1,n)*MT(2,m) + MT(1,m)*MT(2,n))*T1(4,1)*T2(4,2) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,2)*T2(4,2) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(4,2) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(4,2) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,2)*T2(4,2) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(4,3)*T2(4,2) + 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(1,3)*T2(4,3) - 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(1,4)*T2(4,3) - 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(2,3)*T2(4,3) + 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(2,4)*T2(4,3) - 
     -  2*(MT(1,n)*MT(4,m) + MT(1,m)*MT(4,n))*T1(3,1)*T2(4,3) + 
     -  2*(MT(2,n)*MT(4,m) + MT(2,m)*MT(4,n))*T1(3,2)*T2(4,3) + 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(3,4)*T2(4,3) - 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(4,3) + 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(4,3) + 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(3,4)*T2(4,3) + 
     -  2*(MT(1,n)*MT(3,m) + MT(1,m)*MT(3,n))*T1(4,1)*T2(4,3) - 
     -  2*(MT(2,n)*MT(3,m) + MT(2,m)*MT(3,n))*T1(4,2)*T2(4,3) - 
     -  (2*MT(1,m)*MT(1,n) - (2*MT(m,n))/3.)*T1(4,3)*T2(4,3) + 
     -  (2*MT(2,m)*MT(2,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(4,3) - 
     -  (2*MT(3,m)*MT(3,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(4,3) - 
     -  (2*MT(4,m)*MT(4,n) + (2*MT(m,n))/3.)*T1(4,3)*T2(4,3)
           enddo
         enddo
       
       pT(1) = dreal(T(5,1))
       pT(2) = dreal(T(6,1))
       pT(3) = dimag(T(6,1))
       pT(4) = dimag(T(5,1))
       pT2 = pT(1)**2-pT(2)**2-pT(3)**2-pT(4)**2


         do m=1,4
           do n=1,4
          T(m,n)=T(m,n)
     - +((-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,2)*
     -   T2(1,2) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,2)*T2(1,2)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,2)*T2(1,2)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,2)*T2(1,2)
     -   + 2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(1,3)*T2(1,2) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(1,4)*T2(1,2) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,1)*
     -   T2(1,2) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,1)*T2(1,2)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,1)*T2(1,2)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,1)*T2(1,2)
     -   - 2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(2,3)*T2(1,2) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(2,4)*T2(1,2) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(3,1)*T2(1,2) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(3,2)*T2(1,2) - 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(4,1)*T2(1,2) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(4,2)*T2(1,2) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(1,2)*T2(1,3) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,3)*
     -   T2(1,3) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,3)*T2(1,3)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,3)*T2(1,3)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,3)*T2(1,3)
     -   + 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(1,4)*T2(1,3) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(2,1)*T2(1,3) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(2,3)*T2(1,3) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,1)*
     -   T2(1,3) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,1)*T2(1,3)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,1)*T2(1,3)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,1)*T2(1,3)
     -   - 2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(3,2)*T2(1,3) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(3,4)*T2(1,3) - 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(4,1)*T2(1,3) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(4,3)*T2(1,3) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(1,2)*T2(1,4) + 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(1,3)*T2(1,4) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,4)*
     -   T2(1,4) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,4)*T2(1,4)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,4)*T2(1,4)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,4)*T2(1,4)
     -   - 2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(2,1)*T2(1,4) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(2,4)*T2(1,4) - 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(3,1)*T2(1,4) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(3,4)*T2(1,4) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,1)*
     -   T2(1,4) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,1)*T2(1,4)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,1)*T2(1,4)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(4,1)*T2(1,4)
     -   - 2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(4,2)*T2(1,4) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(4,3)*T2(1,4) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,2)*
     -   T2(2,1) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,2)*T2(2,1)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,2)*T2(2,1)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,2)*T2(2,1)
     -   - 2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(1,3)*T2(2,1) - 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(1,4)*T2(2,1) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,1)*
     -   T2(2,1) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,1)*T2(2,1)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,1)*T2(2,1)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,1)*T2(2,1)
     -   + 2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(2,3)*T2(2,1) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(2,4)*T2(2,1) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(3,1)*T2(2,1) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(3,2)*T2(2,1) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(4,1)*T2(2,1) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(4,2)*T2(2,1) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(1,2)*T2(2,3) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(1,3)*T2(2,3) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(2,1)*T2(2,3) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,3)*
     -   T2(2,3) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,3)*T2(2,3)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,3)*T2(2,3)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,3)*T2(2,3)
     -   - 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(2,4)*T2(2,3) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(3,1)*T2(2,3) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,2)*
     -   T2(2,3) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,2)*T2(2,3)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,2)*T2(2,3)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,2)*T2(2,3)
     -   + 2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(3,4)*T2(2,3) + 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(4,2)*T2(2,3) - 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(4,3)*T2(2,3) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(1,2)*T2(2,4) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(1,4)*T2(2,4) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(2,1)*T2(2,4) - 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(2,3)*T2(2,4) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,4)*
     -   T2(2,4) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,4)*T2(2,4)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,4)*T2(2,4)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,4)*T2(2,4)
     -   + 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(3,2)*T2(2,4) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(3,4)*T2(2,4) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(4,1)*T2(2,4) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,2)*
     -   T2(2,4) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,2)*T2(2,4)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,2)*T2(2,4)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(4,2)*T2(2,4)
     -   + 2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(4,3)*T2(2,4) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(1,2)*T2(3,1) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,3)*
     -   T2(3,1) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,3)*T2(3,1)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,3)*T2(3,1)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,3)*T2(3,1)
     -   - 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(1,4)*T2(3,1) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(2,1)*T2(3,1) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(2,3)*T2(3,1) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,1)*
     -   T2(3,1) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,1)*T2(3,1)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,1)*T2(3,1)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,1)*T2(3,1)
     -   + 2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(3,2)*T2(3,1) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(3,4)*T2(3,1) + 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(4,1)*T2(3,1) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(4,3)*T2(3,1) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(1,2)*T2(3,2) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(1,3)*T2(3,2) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(2,1)*T2(3,2) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,3)*
     -   T2(3,2) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,3)*T2(3,2)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,3)*T2(3,2)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,3)*T2(3,2)
     -   + 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(2,4)*T2(3,2) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(3,1)*T2(3,2) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,2)*
     -   T2(3,2) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,2)*T2(3,2)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,2)*T2(3,2)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,2)*T2(3,2)
     -   - 2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(3,4)*T2(3,2) - 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(4,2)*T2(3,2) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(4,3)*T2(3,2) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(1,3)*T2(3,4) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(1,4)*T2(3,4) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(2,3)*T2(3,4) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(2,4)*T2(3,4) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(3,1)*T2(3,4) - 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(3,2)*T2(3,4) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,4)*
     -   T2(3,4) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,4)*T2(3,4)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,4)*T2(3,4)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,4)*T2(3,4)
     -   - 2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(4,1)*T2(3,4) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(4,2)*T2(3,4) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,3)*
     -   T2(3,4) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,3)*T2(3,4)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,3)*T2(3,4)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(4,3)*T2(3,4)
     -   - 2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(1,2)*T2(4,1) - 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(1,3)*T2(4,1) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(1,4)*
     -   T2(4,1) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(1,4)*T2(4,1)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(1,4)*T2(4,1)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(1,4)*T2(4,1)
     -   + 2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(2,1)*T2(4,1) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(2,4)*T2(4,1) + 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(3,1)*T2(4,1) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(3,4)*T2(4,1) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,1)*
     -   T2(4,1) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,1)*T2(4,1)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,1)*T2(4,1)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(4,1)*T2(4,1)
     -   + 2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(4,2)*T2(4,1) + 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(4,3)*T2(4,1) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(1,2)*T2(4,2) - 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(1,4)*T2(4,2) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(2,1)*T2(4,2) + 
     -  2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(2,3)*T2(4,2) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(2,4)*
     -   T2(4,2) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(2,4)*T2(4,2)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(2,4)*T2(4,2)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(2,4)*T2(4,2)
     -   - 2*(-(pT(4)*pT(n)*MT(3,m)) - pT(4)*pT(m)*MT(3,n) - 
     -     pT(3)*pT(n)*MT(4,m) - pT(3)*pT(m)*MT(4,n) + 
     -     (2*pT(3)*pT(4)*MT(m,n))/3.)*T1(3,2)*T2(4,2) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(3,4)*T2(4,2) + 
     -  2*(-(pT(2)*pT(n)*MT(1,m)) - pT(2)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(2,m) - pT(1)*pT(m)*MT(2,n) + 
     -     (2*pT(1)*pT(2)*MT(m,n))/3.)*T1(4,1)*T2(4,2) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,2)*
     -   T2(4,2) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,2)*T2(4,2)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,2)*T2(4,2)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(4,2)*T2(4,2)
     -   - 2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(4,3)*T2(4,2) + 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(1,3)*T2(4,3) - 
     -  2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(1,4)*T2(4,3) - 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(2,3)*T2(4,3) + 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(2,4)*T2(4,3) - 
     -  2*(-(pT(4)*pT(n)*MT(1,m)) - pT(4)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(4,m) - pT(1)*pT(m)*MT(4,n) + 
     -     (2*pT(1)*pT(4)*MT(m,n))/3.)*T1(3,1)*T2(4,3) + 
     -  2*(-(pT(4)*pT(n)*MT(2,m)) - pT(4)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(4,m) - pT(2)*pT(m)*MT(4,n) + 
     -     (2*pT(2)*pT(4)*MT(m,n))/3.)*T1(3,2)*T2(4,3) + 
     -  (2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) - 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(3,4)*
     -   T2(4,3) + (-2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) + 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(3,4)*T2(4,3)
     -   + (2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) - 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(3,4)*T2(4,3)
     -   + (2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) - 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)*T1(3,4)*T2(4,3)
     -   + 2*(-(pT(3)*pT(n)*MT(1,m)) - pT(3)*pT(m)*MT(1,n) - 
     -     pT(1)*pT(n)*MT(3,m) - pT(1)*pT(m)*MT(3,n) + 
     -     (2*pT(1)*pT(3)*MT(m,n))/3.)*T1(4,1)*T2(4,3) - 
     -  2*(-(pT(3)*pT(n)*MT(2,m)) - pT(3)*pT(m)*MT(2,n) - 
     -     pT(2)*pT(n)*MT(3,m) - pT(2)*pT(m)*MT(3,n) + 
     -     (2*pT(2)*pT(3)*MT(m,n))/3.)*T1(4,2)*T2(4,3) + 
     -  (-2*(-(pT(1)*pT(n)*MT(1,m)) - pT(1)*pT(m)*MT(1,n)) + 
     -     (2*(-(pT(m)*pT(n)) - pT(1)**2*MT(m,n)))/3.)*T1(4,3)*
     -   T2(4,3) + (2*(-(pT(2)*pT(n)*MT(2,m)) - 
     -        pT(2)*pT(m)*MT(2,n)) - 
     -     (2*(pT(m)*pT(n) - pT(2)**2*MT(m,n)))/3.)*T1(4,3)*T2(4,3)
     -   + (-2*(-(pT(3)*pT(n)*MT(3,m)) - pT(3)*pT(m)*MT(3,n)) + 
     -     (2*(pT(m)*pT(n) - pT(3)**2*MT(m,n)))/3.)*T1(4,3)*T2(4,3)
     -   + (-2*(-(pT(4)*pT(n)*MT(4,m)) - pT(4)*pT(m)*MT(4,n)) + 
     -     (2*(pT(m)*pT(n) - pT(4)**2*MT(m,n)))/3.)
     -    *T1(4,3)*T2(4,3))/tmass*2

           enddo
         enddo



        if ( tmass.gt.rZero ) then
         d = - 1.0d0/dcmplx( pT2-tmass**2, tmass*twidth )
        else
         d = - 1.0d0/dcmplx( pT2, rZero )
        end if

         do m=1,4
           do n=1,4
          T(m,n)=T(m,n)*gt*d/2.0d0
           enddo
         enddo
c     2.0 factor from propagator convention

         
      wt(1) = T(1,1)
      wt(2) = T(1,2)
      wt(3) = T(1,3)
      wt(4) = T(1,4)
      wt(5) = T(2,1)
      wt(6) = T(2,2)
      wt(7) = T(2,3)
      wt(8) = T(2,4)
      wt(9) = T(3,1)
      wt(10) = T(3,2)
      wt(11) = T(3,3)
      wt(12) = T(3,4)
      wt(13) = T(4,1)
      wt(14) = T(4,2)
      wt(15) = T(4,3)
      wt(16) = T(4,4)
      wt(17) = T(5,1)
      wt(18) = T(6,1)

      return
      end
